@@ -136,6 +136,12 @@ static NSString *inboxFolderName = @"INBOX";
   namespaceDict = [client namespace];
 
   namespace = [namespaceDict objectForKey: @"personal"];
+  // FIXME: Improve MacOSX Ventura support 
+  // Check if the problem will be fixed by Apple or if this fix should be kept in the future
+  // Ticket #5639
+  if ([[context request] isMacOSXVenturaCalendarApp]) {
+    namespace = [namespaceDict objectForKey: @"PERSONAL"];
+  }
   if (namespace)
     [self _appendNamespace: namespace toFolders: folders];
 
