@@ -144,7 +144,7 @@ static SoSecurityManager *sm = nil;
 
 - (NSString *) defaultFolderName
 {
-  return @"Personal";
+  return [[context request] isMacOSXVenturaCalendarApp] ? @"PERSONAL" : @"Personal";
 }
 
 - (NSString *) collectedFolderName
@@ -173,7 +173,7 @@ static SoSecurityManager *sm = nil;
   {
     if (folderType == SOGoPersonalFolder)
     {
-      folderName = @"personal";
+      folderName = [[context request] isMacOSXVenturaCalendarApp] ? @"PERSONAL" : @"personal";
       folder = [subFolderClass objectWithName: folderName inContainer: self];
       [folder setDisplayName: [self defaultFolderName]];
       [folder setOCSPath: [NSString stringWithFormat: @"%@/%@", OCSPath, folderName]];
@@ -221,16 +221,27 @@ static SoSecurityManager *sm = nil;
     while ((row = [fc fetchAttributes: attrs withZone: NULL]))
     {
       key = [row objectForKey: @"c_path4"];
+      // FIXME: Improve MacOSX Ventura support 
+      // Check if the problem will be fixed by Apple or if this fix should be kept in the future
+      // Ticket #5639
+      if ([[context request] isMacOSXVenturaCalendarApp]) {
+        if ([key isEqualToString:@"personal"]) {
+          key = @"PERSONAL";
+        }
+      }
+      
       if ([key isKindOfClass: [NSString class]])
       {
         folder = [subFolderClass objectWithName: key inContainer: self];
-        [folder setOCSPath: [NSString stringWithFormat: @"%@/%@", OCSPath, key]];
+          [folder setOCSPath: [NSString stringWithFormat: @"%@/%@", OCSPath, key]];
+        
+        if (folder)
         [subFolders setObject: folder forKey: key];
       }
     }
     if (folderType == SOGoPersonalFolder)
     {
-      if (![subFolders objectForKey: @"personal"])
+      if (![subFolders objectForKey: @"personal"] || ![subFolders objectForKey: @"Personal"]  || ![subFolders objectForKey: @"PERSONAL"])
         [self createSpecialFolder: SOGoPersonalFolder];
     }
     else if (folderType == SOGoCollectedFolder)
