@@ -833,6 +833,7 @@
             {
               // This additional identity should not appear in the identity manager of the Preferences
               [identity setObject: [NSNumber numberWithBool: YES] forKey: @"isReadOnly"];
+              [identity setObject: [NSNumber numberWithBool: NO] forKey: @"isDefault"];
             }
           [identities addObject: identity];
         }
@@ -1059,7 +1060,7 @@
 
 - (SOGoAppointmentFolder *) personalCalendarFolderInContext: (WOContext *) context
 {
-  return [[self calendarsFolderInContext: context] lookupPersonalFolder: @"personal"
+  return [[self calendarsFolderInContext: context] lookupPersonalFolder: [[context request] isMacOSXVenturaCalendarApp] ? @"PERSONAL" : @"personal"
                                                          ignoringRights: YES];
 }
 
