@@ -805,9 +805,9 @@ NSString *SOGoPasswordRecoverySecondaryEmail = @"SecondaryEmail";
   // Remove possible XSS injection
   mailIdentities = [NSMutableArray arrayWithArray: [self arrayForKey: @"SOGoMailIdentities"]];
   for (i = 0 ; i < [mailIdentities length] ; i++) {
-    mailIdentity = [mailIdentities objectAtIndex: i];
-    if (mailIdentity && [mailIdentity objectForKey: @"fullName"] && [[self arrayForKey: @"SOGoMailIdentities"] isKindOfClass: [NSString class]]) {
-      fullName = [NSString stringWithString: [self arrayForKey: @"SOGoMailIdentities"]];
+    mailIdentity = [NSMutableDictionary dictionaryWithDictionary: [mailIdentities objectAtIndex: i]];
+    if (mailIdentity && [mailIdentity objectForKey: @"fullName"]) {
+      fullName = [NSString stringWithString: [mailIdentity objectForKey: @"fullName"]];
       if (fullName) {
         [mailIdentity setObject: [fullName stringWithoutHTMLInjection: YES] forKey: @"fullName"];
         [mailIdentities setObject: mailIdentity atIndexedSubscript: i];
