@@ -53,6 +53,10 @@
 
 #import "UIxPreferences.h"
 
+#if defined(MFA_CONFIG)
+#include <liboath/oath.h>
+#endif
+
 static NSArray *reminderItems = nil;
 static NSArray *reminderValues = nil;
 
@@ -1340,12 +1344,73 @@ static NSArray *reminderValues = nil;
                         inDictionary: (NSMutableDictionary *) target
 {
   NSArray *identities;
+  SOGoDomainDefaults *dd;
+  NSMutableArray *previousIdentities, *newIdentities;
+  NSMutableDictionary *identity, *newIdentitiesAsDict;
+  int i;
+  BOOL isDefault;
 
   if ([account isKindOfClass: [NSDictionary class]])
     {
+      
       identities = [account objectForKey: @"identities"];
-      if ([self _validateAccountIdentities: identities])
-        [target setObject: identities forKey: @"SOGoMailIdentities"];
+      
+      dd = [[context activeUser] domainDefaults];
+      if ([self _validateAccountIdentities: identities]) {
+        // Disable identity creation for users in preferences
+        if ([dd createIdentitiesDisabled]) {
+          // If create identities is disabled, user can only modify full name and signature
+          previousIdentities = [NSMutableArray arrayWithArray: [[user accountWithName: [account objectForKey: @"name"]] objectForKey: @"identities"]];
+          newIdentities = [NSMutableArray arrayWithArray: identities];
+
+          if ([newIdentities count] <= [previousIdentities count]) {
+            newIdentitiesAsDict = [[NSMutableDictionary alloc] init];
+            for (NSDictionary *identity in identities) {
+              [newIdentitiesAsDict setObject: identity forKey: [identity objectForKey:@"email"]];
+            }
+
+            i = 0;
+            // Remove existing deleted identities
+            for (identity in [user allIdentities]) {
+              // Identity deleted and at least one identity and not the default identity
+              if ([identity objectForKey:@"isDefault"]) {
+                isDefault = [[identity objectForKey:@"isDefault"] boolValue];
+              } else {
+                isDefault = NO;
+              }
+              
+              if (![newIdentitiesAsDict objectForKey: [identity objectForKey:@"email"]] 
+                    && [previousIdentities count] > 1
+                    && !isDefault) {
+                [previousIdentities removeObjectAtIndex: i];
+                i--;
+              }
+              i++;
+            }
+
+            // Update full name, signature and default for existing identities
+            for (identity in previousIdentities) {
+              if ([newIdentitiesAsDict objectForKey: [identity objectForKey:@"email"]]) {
+                  [identity setObject: [[newIdentitiesAsDict objectForKey: [identity objectForKey:@"email"]] objectForKey:@"fullName"] forKey: @"fullName"];
+                  if ([identity objectForKey:@"signature"]) {
+                    [identity setObject: [[newIdentitiesAsDict objectForKey: [identity objectForKey:@"email"]] objectForKey:@"signature"] forKey: @"signature"];
+                  }
+                  if ([[newIdentitiesAsDict objectForKey: [identity objectForKey:@"email"]] objectForKey:@"isDefault"]) {
+                    [identity setObject: [NSNumber numberWithBool: YES] forKey: @"isDefault"];
+                  } else {
+                    [identity setObject: [NSNumber numberWithBool: NO] forKey: @"isDefault"];
+                  }
+              }
+            }
+            [newIdentitiesAsDict release];
+          }
+
+          [target setObject: previousIdentities forKey: @"SOGoMailIdentities"];
+        } else {
+            [target setObject: identities forKey: @"SOGoMailIdentities"];
+        }
+      }
+
       if ([[account objectForKey: @"forceDefaultIdentity"] boolValue])
         [target setObject: [NSNumber numberWithBool: YES] forKey: @"SOGoMailForceDefaultIdentity"];
       else if ([target objectForKey: @"SOGoMailForceDefaultIdentity"])
@@ -1586,6 +1651,69 @@ static NSArray *reminderValues = nil;
             }
         }
 
+
+#if defined(MFA_CONFIG)
+      // Check TOTP token
+      NSString *verificationCode;
+
+      if ([v objectForKey: @"SOGoTOTPEnabled"]
+          && 1 == [[v objectForKey: @"SOGoTOTPEnabled"] intValue]
+          && ![[user userDefaults] totpEnabled]) {
+        
+        verificationCode = [v objectForKey: @"totpVerificationCode"];
+
+        if ([verificationCode length] == 6 && [verificationCode unsignedIntValue] > 0)
+            {
+              unsigned int code;
+              const char *real_secret;
+              char *secret;
+
+              size_t secret_len;
+
+              const auto time_step = OATH_TOTP_DEFAULT_TIME_STEP_SIZE;
+              const auto digits = 6;
+
+              real_secret = [[user totpKey] UTF8String];
+
+              auto result = oath_init();
+              auto t = time(NULL);
+              auto left = time_step - (t % time_step);
+
+              char otp[digits + 1];
+
+              oath_base32_decode (real_secret,
+                                  strlen(real_secret),
+                                  &secret, &secret_len);
+
+              result = oath_totp_generate2(secret,
+                                           secret_len,
+                                           t,
+                                           time_step,
+                                           OATH_TOTP_DEFAULT_START_TIME,
+                                           digits,
+                                           0,
+                                           otp);
+
+              sscanf(otp, "%u", &code);
+
+              oath_done();
+              free(secret);
+
+              if (code != [verificationCode unsignedIntValue])
+                {
+                  results = (id <WOActionResults>) [self responseWithStatus: 485
+                         andJSONRepresentation: [NSDictionary dictionaryWithObjectsAndKeys: @"Invalid TOTP verification code", @"message", nil]];
+                  return results;
+                }
+            } else {
+              results = (id <WOActionResults>) [self responseWithStatus: 485
+                         andJSONRepresentation: [NSDictionary dictionaryWithObjectsAndKeys: @"Invalid TOTP verification code", @"message", nil]];
+              return results;
+            }
+      }
+      [v removeObjectForKey: @"totpVerificationCode"];
+#endif
+
       [[[user userDefaults] source] setValues: v];
 
       if ([[user userDefaults] synchronize] && [self userHasMailAccess])
@@ -1674,4 +1802,9 @@ static NSArray *reminderValues = nil;
   return [self shouldDisplayPasswordRecovery] || [self shouldDisplayPasswordChange];
 }
 
+- (BOOL) isEasUIEnabled
+{
+  return ![[SOGoSystemDefaults sharedSystemDefaults] isEasUIDisabled];
+}
+
 @end
